@@ -1,13 +1,11 @@
-import UtilsController
-import LogController as logController
+import TimeLineCluster.LogController as LogController
 from datetime import datetime
 
 class GenericControllerClass:
-    def __init__(self, app="", path_generic_app="", path_log_app=""):
-        self.app_name = app
-        self.log = logController.LogController("", app, path_log_app)
-        self.flag_data = UtilsController.getFlagData()
-        self.data_app_config = UtilsController.readFileJson(path_generic_app)
+    def __init__(self, data_for_time_line_cluster):
+        self.app_name = data_for_time_line_cluster["app_name"]
+        self.log = LogController.LogController("", data_for_time_line_cluster["app_name"], data_for_time_line_cluster["log_path"])
+        self.data_app_config = data_for_time_line_cluster["data_app_config"]
         self.msg_error = ""
 
         if(self.data_app_config == False):
@@ -15,22 +13,16 @@ class GenericControllerClass:
             print("App not found !!")
             return 
 
-        self.controller_app = {}
-
-        if("report" in self.data_app_config["controller_app"]):
-            module = __import__("controller." + app + ".ReportController", fromlist=["ReportController"])
-            my_class = getattr(module, "ReportController")
-            self.controller_app["report"] = my_class
-
-        if("member" in self.data_app_config["controller_app"]):
-            module = __import__("controller." + app + ".MemberController", fromlist=["MemberController"])
-            my_class = getattr(module, "MemberController")
-            self.controller_app["member"] = my_class
-
-        if("summary" in self.data_app_config["controller_app"]):
-            module = __import__("controller." + app + ".SummaryController", fromlist=["SummaryController"])
-            my_class = getattr(module, "SummaryController")
-            self.controller_app["summary"] = my_class
+        if(len(data_for_time_line_cluster["controller"]) == 3):
+            self.controller_app = {
+                "member" : data_for_time_line_cluster["controller"]["member"],
+                "summary": data_for_time_line_cluster["controller"]["summary"],
+                "report" : data_for_time_line_cluster["controller"]["report"]
+            }
+        else:
+            self.msg_error = "Controller not found !!"
+            print("Controller not found !!")
+            return 
 
     def exploreCluster(self, connect_db_output, source, unique_source_data, i,source_by_create_date, data_cluster_representative, flag_data, generic):
         try:
